@@ -5,10 +5,16 @@ Requires: pillow, which is an optional project dependency.
 :author: Shay Hill
 :created: 7/26/2020
 """
+
+# Ignore missing module source for optional dependency pillow. A type: ignore on the
+# import line gets flagged an unnecessary when I have pillow installed for testing.
+# pyright: reportMissingModuleSource=false
+
+
 from __future__ import annotations
 
 try:
-    from PIL import Image  # type: ignore
+    from PIL import Image
 except ModuleNotFoundError as exc:
     MSG = "`pip install pillow` to use svg_ultralight.animate module"
     raise ModuleNotFoundError(MSG) from exc
