@@ -11,6 +11,7 @@ I borrowed test values and and conventions from Inkscape's `inkek.units.py`.
 import dataclasses
 import enum
 import re
+from typing import Optional, Union
 
 from svg_ultralight.string_conversion import format_number
 
@@ -46,15 +47,16 @@ class Unit(enum.Enum):
 
 
 # the arguments this module will attempt to interpret as a string with a unit specifier
-MeasurementArg = (
-    float
-    | str
-    | tuple[str, str]
-    | tuple[float, str]
-    | tuple[str, Unit]
-    | tuple[float, Unit]
-    | Unit
-)
+MeasurementArg = Union[
+    float,
+    str,
+    tuple[str, str],
+    tuple[float, str],
+    tuple[str, Unit],
+    tuple[float, Unit],
+    Unit,
+]
+
 
 _UNIT_SPECIFIER2UNIT = {x.value[0]: x for x in Unit}
 
@@ -90,10 +92,11 @@ def _parse_unit(measurement_arg: MeasurementArg) -> tuple[float, Unit]:
     | (str, Unit)   | ("55.32", Unit.PX) | (55.32, Unit.PX)   |
     | (float, Unit) | (55.32, Unit.PX)   | (55.32, Unit.PX)   |
     | Unit          | Unit.PX            | (0.0, Unit.PX)     |
+    | Measurement   | Measurement("3in") | (3.0, Unit.IN)     |
 
     """
     failure_msg = f"Cannot parse value and unit from {measurement_arg}"
-    unit: str | Unit
+    unit: Union[str, Unit]
     try:
         if isinstance(measurement_arg, tuple):
             number, unit = float(measurement_arg[0]), measurement_arg[1]
@@ -140,7 +143,7 @@ class Measurement:
         value, self.native_unit = _parse_unit(measurement_arg)
         self.value = value * self.native_unit.value[1]
 
-    def get_value(self, unit: Unit | None = None) -> float:
+    def get_value(self, unit: Optional[Unit] = None) -> float:
         """Get the measurement in the specified unit.
 
         :param unit: optional unit to convert to
@@ -155,7 +158,37 @@ class Measurement:
             unit = _UNIT_SPECIFIER2UNIT[unit]
         return self.value / unit.value[1]
 
-    def get_str(self, unit: Unit | None = None) -> str:
+    def get_tuple(self, unit: Optional[Unit] = None) -> tuple[float, Unit]:
+        """Get the measurement as a tuple of value and unit.
+
+        :param unit: optional unit to convert to
+        :return: value in specified as a tuple
+        """
+        return self.get_value(unit), unit or Unit.USER
+
+    def get_str(self, unit: Optional[Unit] = None) -> str:
+        """Get the measurement in the specified unit as a string.
+
+        :param optional unit: the unit to convert to
+        :return: the measurement in the specified unit as a string
+
+        The input arguments for groups of measurements are less flexible than for
+        single measurements. Single measurements can be defined by something like
+        `(1, "in")`, but groups can be passed as single or tuples, so there is no way
+        to differentiate between (1, "in") and "1in" or (1, "in") as ("1", "0in").
+        That is a limitation, but doint it that way preserved the flexibility (and
+        backwards compatibility) of being able to define padding as "1in" everywhere
+        or (1, 2, 3, 4) for top, right, bottom, left.
+
+        The string from this method is different from the string in the `get_svg`
+        method, because this string will print a full printable precision, while the
+        svg string will print a reduced precision. So this string can be used to as
+        an argument to pad or print_width without losing precision.
+        """
+        value, unit = self.get_tuple(unit)
+        return f"{value}{unit.value[0]}"
+
+    def get_svg(self, unit: Optional[Unit] = None) -> str:
         """Get the measurement in the specified unit as it would be written in svg.
 
         :param optional unit: the unit to convert to
@@ -164,19 +197,10 @@ class Measurement:
         Rounds values to 6 decimal places as recommended by svg guidance online.
         Higher precision just changes file size without imroving quality.
         """
+        value, unit = self.get_tuple(unit)
         value = format_number(self.get_value(unit))
-        if unit is None:
-            return value
         return f"{value}{unit.value[0]}"
 
-    @property
-    def native(self) -> str:
-        """Get the value in the native unit.
-
-        :return: self.value in initial unit used to init Measurement instance
-        """
-        return self.get_str(self.native_unit)
-
     def __add__(self, other: "Measurement") -> "Measurement":
         """Add two measurements.
 
